///
/// Copyright 2006 Attrice Corporation, http://www.attrice.info 
/// This software is a freeware and may be used under Attrice Sidekicks License
/// (download updated license from http://www.attrice.info/downloads/sidekick_license.txt)
/// Feedback or questions? Contact us at info@attrice.info
///
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Configuration.Install;
using System.IO;
using System.Xml;

namespace SetupCustom
{
    /// <summary>
    /// Custom setup module that updates addin XML file contents
    /// </summary>
    [RunInstaller(true)]
    public partial class CustomInstaller : Installer
    {
        public CustomInstaller()
        {
            InitializeComponent();
        }

        private const string cAddinConfigFileName = "Visual Studio 2005\\Addins\\SidekicksAddin.addin";
        private const string cAddinFileName = "SidekicksAddin.dll";

        public override void  Install(System.Collections.IDictionary stateSaver)
        {
 	        base.Install(stateSaver);
            string addinFileName = String.Empty;
            try
            {
                // get app path from installer
                String applicationPath = Context.Parameters["ApplicationPath"];
                // get user path from installer
                String userPath = Context.Parameters["UserPath"];
                if (applicationPath == null || userPath == null)
                    throw new ApplicationException("Invalid action parameter");
                // fix the UNC user path problem
                if (userPath.StartsWith(@"\") && !userPath.StartsWith(@"\\"))
                    userPath = @"\" + userPath;
                addinFileName = Path.Combine(userPath, cAddinConfigFileName);
                if (!File.Exists(addinFileName))
                    throw new ApplicationException(String.Format("File {0} does not exist", addinFileName));
                XmlDocument document = new XmlDocument();
                document.Load(addinFileName);
                // update addin XML with path
                XmlNode node = document["Extensibility"];
                if (node == null)
                    throw new ApplicationException("File .addin has invalid format (extensibility)");
                node = node["Addin"];
                if (node == null)
                    throw new ApplicationException("File .addin has invalid format (addin)");
                node = node["Assembly"];
                if (node == null)
                    throw new ApplicationException("File .addin has invalid format (assembly)");
                node.InnerText = Path.Combine(applicationPath, cAddinFileName);
                document.Save(addinFileName);
            }
            catch (Exception ex)
            {
                if (ex is ApplicationException)
                    throw ex;
                throw new ApplicationException(String.Format("Failed to update add-in XML file at {0} [[1}]", addinFileName,
                    ex.Message), ex);
            }
        }
    }
}