///
/// Copyright 2006 Attrice Corporation, http://www.attrice.info 
/// This software is a freeware and may be used under Attrice Sidekicks License
/// (download updated license from http://www.attrice.info/downloads/sidekick_license.txt)
/// Feedback or questions? Contact us at info@attrice.info
///
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Win32;
using System.Windows.Forms;

namespace Attrice.VisualStudioIntegration.Tfs
{
    /// <summary>
    /// Configuration wrapper for addin. Persisist configuration values in 
    /// registry.
    /// </summary>
    public class AddinConfiguration
    {
        private static AddinConfiguration _configuration;

        static AddinConfiguration()
        {
            _configuration = new AddinConfiguration();
        }

        private bool _editExternal;
        private bool _dynamicHistory;
        private string _externalPath;

        public static bool EditExternal
        {
            get
            {
                return _configuration._editExternal;
            }
            set
            {
                _configuration._editExternal = value;
            }
        }

        public static string ExternalPath
        {
            get
            {
                return _configuration._externalPath;
            }
            set
            {
                _configuration._externalPath = value;
            }
        }

        public static bool DynamicHistory
        {
            get
            {
                return _configuration._dynamicHistory;
            }
            set
            {
                _configuration._dynamicHistory = value;
            }
        }

        public static void Load()
        {
            RegistryKey key = null;
            try
            {
                key = Registry.CurrentUser.OpenSubKey("SOFTWARE\\Attrice Corporation\\Team Build Sidekick", false);
                if (key != null)
                {
                    _configuration._externalPath = key.GetValue("ExternalPath", "") as String;
                    _configuration._editExternal = ((int)key.GetValue("EditExternal", 0)) == 1;
                    _configuration._dynamicHistory = ((int)key.GetValue("DynamicHistory", 0)) == 1;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Failed to read registry." + ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            finally
            {
                if (key != null)
                    key.Close();
            }
        }

        public static void Save()
        {
            RegistryKey key = null;
            try
            {
                key = Registry.CurrentUser.CreateSubKey("SOFTWARE\\Attrice Corporation\\Team Build Sidekick");
                key.SetValue("ExternalPath", _configuration._externalPath, RegistryValueKind.String);
                key.SetValue("EditExternal", _configuration._editExternal ? 1 : 0, RegistryValueKind.DWord);
                key.SetValue("DynamicHistory", _configuration._dynamicHistory ? 1 : 0, RegistryValueKind.DWord);
            }
            catch (Exception ex)
            {
                MessageBox.Show("Failed to update registry." + ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            finally
            {
                if (key != null)
                    key.Close();
            }
        }

        private AddinConfiguration()
        {
            _editExternal = false;
            _externalPath = "";
            _dynamicHistory = false;
        }
    }
}
